@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2014 Red Hat, Inc.
+# Copyright (C) 2014-2015 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +17,6 @@
 
 
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-dwh')
 
 
 from otopi import util
@@ -25,7 +24,13 @@ from otopi import plugin
 
 
 from ovirt_engine_setup.dwh import constants as odwhcons
-from ovirt_engine_setup.dwh import engine_db_timekeeping
+from ovirt_engine_setup.engine import constants as oenginecons
+from ovirt_engine_setup.engine_common import dwh_history_timekeeping as \
+    engine_db_timekeeping
+
+
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-engine-dwh')
 
 
 @util.export
@@ -39,7 +44,7 @@ class Plugin(plugin.PluginBase):
     )
     def _init(self):
         self.environment.setdefault(
-            odwhcons.RemoveEnv.REMOVE_ENGINE_DATABASE,
+            oenginecons.RemoveEnv.REMOVE_ENGINE_DATABASE,
             False,
         )
 
@@ -50,7 +55,7 @@ class Plugin(plugin.PluginBase):
         ),
         condition=lambda self: (
             self.environment[odwhcons.CoreEnv.ENABLE] and
-            not self.environment[odwhcons.RemoveEnv.REMOVE_ENGINE_DATABASE]
+            not self.environment[oenginecons.RemoveEnv.REMOVE_ENGINE_DATABASE]
         ),
     )
     def _misc(self):
@@ -79,7 +84,7 @@ class Plugin(plugin.PluginBase):
                     name=engine_db_timekeeping.DB_KEY_UUID,
                     value=''
                 )
-        except RuntimeError as e:
+        except Exception as e:
             self.logger.debug('exception', exc_info=True)
             self.logger.warning(
                 _(
